==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/QuobyteVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class QuobyteVolumeSourceBuilder extends io.fabric8.kubernetes.api.model.QuobyteVolumeSourceFluentImpl<io.fabric8.kubernetes.api.model.QuobyteVolumeSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.QuobyteVolumeSource,io.fabric8.kubernetes.api.model.QuobyteVolumeSourceBuilder>{
  public QuobyteVolumeSourceBuilder() {
    this(false);
  }
  public QuobyteVolumeSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new QuobyteVolumeSource(), validationEnabled);
  }
  public QuobyteVolumeSourceBuilder(io.fabric8.kubernetes.api.model.QuobyteVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public QuobyteVolumeSourceBuilder(io.fabric8.kubernetes.api.model.QuobyteVolumeSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new QuobyteVolumeSource(), validationEnabled);
  }
  public QuobyteVolumeSourceBuilder(io.fabric8.kubernetes.api.model.QuobyteVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.QuobyteVolumeSource instance) {
    this(fluent, instance, false);
  }
  public QuobyteVolumeSourceBuilder(io.fabric8.kubernetes.api.model.QuobyteVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.QuobyteVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGroup(instance.getGroup()); 
    fluent.withReadOnly(instance.getReadOnly()); 
    fluent.withRegistry(instance.getRegistry()); 
    fluent.withTenant(instance.getTenant()); 
    fluent.withUser(instance.getUser()); 
    fluent.withVolume(instance.getVolume()); 
    this.validationEnabled = validationEnabled; 
  }
  public QuobyteVolumeSourceBuilder(io.fabric8.kubernetes.api.model.QuobyteVolumeSource instance) {
    this(instance,false);
  }
  public QuobyteVolumeSourceBuilder(io.fabric8.kubernetes.api.model.QuobyteVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withGroup(instance.getGroup()); 
    this.withReadOnly(instance.getReadOnly()); 
    this.withRegistry(instance.getRegistry()); 
    this.withTenant(instance.getTenant()); 
    this.withUser(instance.getUser()); 
    this.withVolume(instance.getVolume()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.QuobyteVolumeSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.QuobyteVolumeSource build() {
    QuobyteVolumeSource buildable = new QuobyteVolumeSource(fluent.getGroup(),fluent.getReadOnly(),fluent.getRegistry(),fluent.getTenant(),fluent.getUser(),fluent.getVolume());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    QuobyteVolumeSourceBuilder that = (QuobyteVolumeSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.1-sources.jar: io/fabric8/kubernetes/api/model/QuobyteVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class QuobyteVolumeSourceBuilder extends io.fabric8.kubernetes.api.model.QuobyteVolumeSourceFluentImpl<io.fabric8.kubernetes.api.model.QuobyteVolumeSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.QuobyteVolumeSource,io.fabric8.kubernetes.api.model.QuobyteVolumeSourceBuilder>{
  public QuobyteVolumeSourceBuilder() {
    this(false);
  }
  public QuobyteVolumeSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new QuobyteVolumeSource(), validationEnabled);
  }
  public QuobyteVolumeSourceBuilder(io.fabric8.kubernetes.api.model.QuobyteVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public QuobyteVolumeSourceBuilder(io.fabric8.kubernetes.api.model.QuobyteVolumeSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new QuobyteVolumeSource(), validationEnabled);
  }
  public QuobyteVolumeSourceBuilder(io.fabric8.kubernetes.api.model.QuobyteVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.QuobyteVolumeSource instance) {
    this(fluent, instance, false);
  }
  public QuobyteVolumeSourceBuilder(io.fabric8.kubernetes.api.model.QuobyteVolumeSourceFluent<?> fluent,io.fabric8.kubernetes.api.model.QuobyteVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGroup(instance.getGroup()); 
    fluent.withReadOnly(instance.getReadOnly()); 
    fluent.withRegistry(instance.getRegistry()); 
    fluent.withTenant(instance.getTenant()); 
    fluent.withUser(instance.getUser()); 
    fluent.withVolume(instance.getVolume()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public QuobyteVolumeSourceBuilder(io.fabric8.kubernetes.api.model.QuobyteVolumeSource instance) {
    this(instance,false);
  }
  public QuobyteVolumeSourceBuilder(io.fabric8.kubernetes.api.model.QuobyteVolumeSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withGroup(instance.getGroup()); 
    this.withReadOnly(instance.getReadOnly()); 
    this.withRegistry(instance.getRegistry()); 
    this.withTenant(instance.getTenant()); 
    this.withUser(instance.getUser()); 
    this.withVolume(instance.getVolume()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.QuobyteVolumeSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.QuobyteVolumeSource build() {
    QuobyteVolumeSource buildable = new QuobyteVolumeSource(fluent.getGroup(),fluent.getReadOnly(),fluent.getRegistry(),fluent.getTenant(),fluent.getUser(),fluent.getVolume());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    QuobyteVolumeSourceBuilder that = (QuobyteVolumeSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
